Magnetic Temperature Scale in the 2 K to 30 K Range - IOPscience
Author: D N Astrov
Date: 1976-10-01

This site uses cookies. By continuing to use this site you agree to our use of cookies. To find out more, see our Privacy and Cookies policy.
Close this notification
Metrologia

The International Bureau of Weights and Measures (BIPM) was set up by the Metre Convention and has its headquarters near Paris, France. It is financed jointly by its Member States and operates under the exclusive supervision of the CIPM.

Its mandate is to provide the basis for a single, coherent system of measurements throughout the world, traceable to the International System of Units (SI). This task takes many forms, from direct dissemination of units (as in the case of mass and time) to coordination through international comparisons of national measurement standards (as in electricity and ionizing radiation).

The BIPM has an international staff of over 70 and its status vis-à-vis the French Government is similar to that of other intergovernmental organizations based in Paris.

# Magnetic Temperature Scale in the 2 K to 30 K Range

D N Astrov1, V A Pavlov1 and V T Shkraba1

Published under licence by IOP Publishing Ltd
Metrologia, Volume 12, Number 4 Citation D N Astrov et al 1976 Metrologia 12 143 DOI 10.1088/0026-1394/12/4/002

Download Article PDF

## Article metrics

44 Total downloads

## MathJax

Turn off MathJax Turn on MathJax

## Permissions

Get permission to re-use this article

## Share this article

Article and author information

## Author affiliations

1 The Physico-Technical and Radio-Technical Measurements Institute (PRMI), Moscow, USSR

## Dates

1. Received 22 February 1975

Buy this article in print

Journal RSS
Sign up for new issue notifications
0026-1394/12/4/143

## Abstract

In the temperature range from 2 to 30 K a comparison has been made of a magnetic thermometer based on the magnetic susceptibilities of manganous ammonium sulfate (MAS) and gadolinium molybdate (GM) with the readings of a germanium resistance thermometer. The magnetic susceptibility was measured by a screened selfchecking mutual inductance bridge with an uncertainty of the relative measurements being not worse that ±5 × 10-6. The magnetic thermometer sensitivity near 30 K is 0.3 mK with MAS and 0.07 mK with GM. The magnetic thermometer was calibrated in terms of the IPTS-68 and T58 temperature scale with an uncertainty of ±0.5 mK. The magnetic temperature scale was determined using the MAS data obtained in three experimental runs and GM data taken in two runs. The scale was transferred on a germanium resistance thermometer with a root-mean-square deviation of the data from the smooth curve of 0.7 mK. The inconsistency previously reported in the literature between the IPTS-68 and the T58 temperature scale has been confirmed. The helium normal boiling point temperature on the T58 scale is according to our data too low and must be raised by 9.5 ± 1.5 mK. An indirect comparison of our magnetic temperature scale with the results obtained by Van Rijn and Durieux as well as with those by Cetas and Swenson has been carried out in terms of the NBS P 2-20 K scale. The estimated difference between our data and the results of the above authors does not exceed ±3 mK.

Export citation and abstract BibTeX RIS

10.1088/0026-1394/12/4/002

## You may also like